# This script reproduces Table 12.16 in ARM4

library(TAM)
library(dplyr)
library(lavaan)

# Data preparation:
blot <- read.csv("BLOT.csv", header = FALSE, sep = ";")
colnames(blot)[1] <- c("id")
colnames(blot)[2:49] <- paste("blot", (1:48), sep ="")

blot_items <- dplyr::select(blot, id, blot1:blot35)

prt <- read.csv("PRTIII.csv", header = FALSE, sep = ";")
colnames(prt)[1] <- c("id")
colnames(prt)[2:14] <- paste("prt", (1:13), sep = "")

df_pre <- merge(blot_items, prt, by = "id") # Merge data
df <- df_pre[,-c(1)] # Drop id column. Not needed for the TAM analysis

################################
# TAM dimensionality analysis: #
################################

# tamaan specification of a two-dimensional Rasch model with correlated factors:
tammodel <- '

LAVAAN MODEL:
F1 =~ 1*blot1__blot35
F2 =~ 1*prt1__prt13


F1 ~~ F1
F2 ~~ F2
F1 ~~ F2

 '

tam_2d <- TAM::tamaan(tammodel, df, control = list(maxiter = 300)) # Fit the model
summary(tam_2d)
IRT.modelfit(tam_2d)

# Fit a *unidimensional* Rasch model using TAM:
fit_rasch_1d_tam <- TAM::tam.mml(df)

# Compare models: See Table 12.16 in ARM4
IRT.compareModels(fit_rasch_1d_tam, tam_2d)